@@ -222,9 +222,8 @@ class Container(object):
 
             env_vars = self.config.prepare_docker_env_vars()
 
-            wrapped_command = 'docker run -v {project}:{project}:Z -v {home}:{home}:Z {env} {go} {rust} -w {cwd} -u {uid} --rm {tty} {network} -i {image} bash -c "{cmd}"'.format(
+            wrapped_command = 'docker run -v {project}:{project}:Z {env} {go} {rust} -w {cwd} -u {uid} --rm {tty} {network} -i {image} bash -c "{cmd}"'.format(
                 project=cwd,
-                home=self.config.build_home,
                 env=env_vars,
                 go=go_config,
                 rust=rust_config,
@@ -378,9 +377,10 @@ RUN {}
                 use_build_dir=False,
             ).strip()
             version = int(version_string)
+        except ClickableException as e:
+            raise e
         except Exception as e:
             logger.warn("Could not read the image version from the container")
-            pass
 
         if version < self.minimum_version:
             raise ClickableException('This version of Clickable requires a newer version of the docker images than installed. Please run "clickable update" to update your local images.')
@@ -390,7 +390,8 @@ RUN {}
         if self.config.is_custom_docker_image:
             return
 
-        self.check_base_image_version()
+        if not self.config.container_mode:
+            self.check_base_image_version()
 
         if not self.needs_customized_container():
             return
